<?php
global $wpdb, $wp_version;

$options      = WP_Cache_On::get_options();
$size         = WP_Cache_On_Disk::get_cache_size();
$minifySelect = WP_Cache_On::minify_select();

// DB size
$db_size = $wpdb->get_var("SELECT sum(round(((data_length + index_length) / 1024), 2)) FROM information_schema.tables WHERE table_schema = '" . DB_NAME . "'");

if ($db_size >= 1024) {
    $db_size = round(($db_size / 1024), 2) . " MB";
} else {
    $db_size = round($db_size, 2) . " KB";
}
?>

<div class="content-max-width">
	<div class="overview-box-top">
		<div class="overview-box-head"><?php _e('Overview', 'wp-cache-on');?></div>
		<ul class="overview-box-line fixed">
			<li>
				<div class="overview-text-left"><?php _e('WP Version', 'wp-cache-on');?>:&nbsp;</div>
				<div class="overview-text-right"><?php echo $wp_version; ?></div>
			</li>
			<li>
				<div class="overview-text-left"><?php _e('Database size', 'wp-cache-on');?>:&nbsp;</div>
				<div class="overview-text-right"><?php echo $db_size; ?></div>
			</li>
			<li>
				<div class="overview-text-left"><?php _e('Local date &amp; time', 'wp-cache-on');?>:&nbsp;</div>
				<div class="overview-text-right"><?php echo date_i18n('Y-m-d, H:i:s'); ?></div>
			</li>
			<li>
				<div class="overview-text-left"><?php _e("Current cache size", "wp-cache-on");?>:&nbsp;</div>
				<div class="overview-text-right"><?php echo (empty($size) ? _e("Empty", "wp-cache-on") : size_format($size)); ?></div>
			</li>
			<li>
				<snap class="overview-text">
					<?php _e("By default the plugin is configured to it's cutting edge, so it could improve your website speed without the need of additional configuration. If you would like to perform changes over the plugin cache settings, you can perform them on this page.", 'wp-cache-on');?>
				</snap>
			</li>
		</ul>
	</div>

	<div class="overview-box-bottom">
		<div class="overview-box-head"><?php _e('Settings', 'wp-cache-on');?></div>

		<form action="options.php" method="POST">
			<?php settings_fields('wp-cache-on')?>
			<ul class="settings-box-line ">

				<li>
					<?php _e("Cache Expiration:", "wp-cache-on");?>
					<input type="text" class="custom-medium" name="wp-cache-on[expires]" value="<?php echo esc_attr($options['expires']); ?>" style="float:right"/>

					<div class="overview-setting-desc">
						<?php _e("Set for how many hours the cache will be used before removed and new cache generated. If you would not like the cache to expire set the value to '0'.", "wp-cache-on");?>
					</div>
				</li>

				<li>
					<?php _e("Turn off caching for:", "wp-cache-on")?>
					<input type="text" class="custom-medium" name="wp-cache-on[excl_ids]" value="<?php echo esc_attr($options['excl_ids']) ?>" style="float:right"/>

					<div class="overview-setting-desc">
						<?php _e("List the ID of a page or post separated by a <code>,</code> that you would like to be not cached.", "wp-cache-on");?>
					</div>
				</li>

				<li>
					<?php _e("Cache Minification", "wp-cache-on")?>

					<select name="wp-cache-on[minify]"  class="sel-minification" >
						<?php foreach ($minifySelect as $k => $v) {?>
							<option value="<?php echo esc_attr($k) ?>" <?php selected($options['minify'], $k);?>>
								<?php echo esc_html($v) ?>
							</option>
						<?php }?>
					</select>

					<div class="overview-setting-desc">
						<?php _e("The minification options are: Disabled, to disable minification. HTML to minify only the HTML content. HTML & Inline JS will minify everything.", "wp-cache-on");?>
					</div>
				</li>
			</ul>
			<?php submit_button()?>
		</form>
	</div>
	<div class="clear-both"></div>
</div>