<?php
/**
 * Provide a admin area view for the plugin
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @since      2.0.0
 * @package    WP_Cache_On
 * @subpackage WP_Cache_On/admin/partials
 * @author     Jeffrey Cooper <email@example.com>
 */

class WP_Cache_On_Admin_Display
{
    public static function settings_page()
    {
        if (!defined('WP_CACHE') || !WP_CACHE) {
            echo sprintf(
                '<div class="notice notice-warning"><p>%s</p></div>',
                sprintf(
                    __("%s is not set in %s.", 'wp-cache-on'),
                    "<code>define('WP_CACHE', true);</code>",
                    "wp-config.php"
                )
            );
        }

        $options     = WP_Cache_On::get_options();
        $size        = WP_Cache_On_Disk::get_cache_size();
        $lastVersion = self::getPluginVersionFromRepository('wpcacheon');
        ?>
    <div class="wrap">
        <div>
            <table width="100%" cellspacing="0">
                <tr style="background:#fff;border:0px solid #eee;">

                    <td style="padding:10px 10px 10px 20px">
                        <img src="<?php echo WCO_PLUGIN_DIR_PATH; ?>/admin/images/logo.png"/>
                    </td>

                    <td width="100%">
                        <div style="background:#fff;padding:10px;margin-bottom:10px;">
                            <div style="font-size: 20px;font-weight: 400;margin-bottom:10px">
                                <?php _e("WPCacheOn", "wp-cache-on") . " " . WCO_VERSION?>
                                <?php if (WCO_VERSION != $lastVersion) {?>
                                    <a href="<?php echo  admin_url('update-core.php'); ?>"><span style="font-size:small;">(Update available)</span></a>
                                <?php }?>
                            </div>
                            <div style="border-top:1px dashed #eee;padding-top:4px">
                                <span class="row-text"><?php _e('By', 'wp-cache-on');?></span>
                                <a class="sidebar-link" href="https://profiles.wordpress.org/jeffreycooper/" target="_blank">Jeffrey Cooper</a>
                                &nbsp;|&nbsp;
                                <span class="row-text"><?php _e('Need help?', 'wp-cache-on');?></span>
                                <a class="sidebar-link" href="https://wpcacheon.io/contact/" target="_blank"><?php _e('Contact us!', 'wp-cache-on');?></a>
                            </div>
                        </div>
                    </td>

                    <td style="text-align:center">
                        <div style="background:#fff;padding:10px;margin-bottom:10px;">
                            <a class="sidebar-link" href="https://wpcacheon.io/contact/" target="_blank">
                                <img style="width:50px" src="<?php echo WCO_PLUGIN_DIR_PATH; ?>/admin/images/help.svg"/>
                                <br/>
                                <span><?php _e('Support', 'wp-cache-on');?></span>
                            </a>
                        </div>
                    </td>
                </tr>
            </table>
        </div>

        <h1 style="font-size:10px"></h1>

        <div class="margin-r-300">
            <div class="tab-box">
        <?php

        $tabs = array(
            'settings' => array("name" => __('Settings', 'wp-cache-on'), "css" => 'dashicons-admin-settings dashicons'),
        );

        $current_tab = isset($_GET['tab']) ? $_GET['tab'] : 'settings';

        // echo '<h2 class="nav-tab-wrapper">';
        // foreach ($tabs as $tab => $property) {
        //     $class = ($tab == $current_tab) ? 'nav-tab-active' : '';
        //     echo "<a class='nav-tab $class' href='?page=wp-cache-on&tab=$tab'><span class='" . $property['css'] . "'></span>" . $property['name'] . "</a>";
        // }
        // echo '</h2>';

        echo '<div class="tab-box-div">';

        switch ($current_tab) {
            case 'settings':
                include_once WCO_DIR . '/admin/partials/settings.php';
                break;
        }
        echo '</div>';
        ?>
            </div>

            <div class="sidebar">
                <div style="margin-top:-41px">
                    <div id="upgrade">
                            <img src="<?php echo WCO_PLUGIN_DIR_PATH; ?>/admin/images/logo.png" />

                            <p>
                                    <?php echo sprintf(
            __('If you love this plugin and would like support us, you can like our %s page, follow us on %s or become a %s. You are awasome.', 'wp-cache-on'),
            '<a target="_blank" href="https://www.facebook.com/wpcacheon">Facebook</a>',
            '<a target="_blank" href="https://twitter.com/wpcacheon">Twitter</a>',
            '<a target="_blank" href="https://www.patreon.com/wpcacheon">Patreon</a>'
        ); ?>
                                <br/>
                                <span style="float:right">
                                    <?php _e('Thank you!', 'wp-cache-on');?>
                                </span>
                                <br/>
                            </p>

                            <center style="padding-bottom:20px">
                                    <a href="https://www.patreon.com/bePatron?u=8652264" data-patreon-widget-type="become-patron-button">Become a Patron!</a><script async src="https://c6.patreon.com/becomePatronButton.bundle.js"></script>
                            </center>

                            <div style="text-align:center;border-top:1px dashed #ccc;color:#999"></div>
                            <p>
                                <a href="https://wordpress.org/support/plugin/wpcacheon/reviews/?filter=5#new-post" target="_blank" class="rate-us"><?php _e('Please rate us', 'wp-cache-on');?>  <img style="float:right" src="<?php echo WCO_PLUGIN_DIR_PATH; ?>/admin/images/rate.png"/></a>
                            </p>
                    </div>
                </div>
            </div>

        </div>
    </div>

   <?php
}

    // returns version of the plugin represented by $slug, from repository
    public static function getPluginVersionFromRepository($slug)
    {
        $url      = "https://api.wordpress.org/plugins/info/1.2/?action=plugin_information&request[slugs][]={$slug}";
        $response = wp_remote_get($url); // WPOrg API call
        $plugins  = json_decode($response['body']);

        // traverse $response object
        foreach ($plugins as $key => $plugin) {
            $version = $plugin->version;
        }
        return $version;
    }
}