<?php
/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      2.0.0
 * @package    WP_Cache_On
 * @subpackage WP_Cache_On/includes
 * @author     Jeffrey Cooper <email@example.com>
 */
class WP_Cache_On_Activator
{
    /**
     * Short Description. (use period)
     *
     * Long Description.
     *
     * @since    1.0.0
     */
    public static function activate()
    {
        if (is_multisite() && !empty($_GET['networkwide'])) {
            $ids = WP_Cache_On_General::_get_blog_ids(); //Blog ids

            //Switch to blog
            foreach ($ids as $id) {
                switch_to_blog($id);
                self::_install_backend();
            }

            restore_current_blog();
        } else {
            self::_install_backend();
        }

        WP_Cache_On_General::htaccess_action(true);

        copy(WCO_DIR . '/includes/advanced-cache.php', WP_CONTENT_DIR . '/advanced-cache.php');
    }

    /**
     * Installation options
     */
    private static function _install_backend()
    {
        add_option('wp-cache-on', array());

        WP_Cache_On_Disk::clear_total_cache(true);

        //Set right permision of files and folders if possible.
        // If can`t set it will show errors based on missing permision
        try {
            if (!file_exists(WCO_CACHE_DIR)) {
                mkdir(WCO_CACHE_DIR, 0775, true);
            }

            chmod(ABSPATH . '.htaccess', 0644);
        } catch (Exception $e) {
            error_log('[WCO] Caught exception: ' . $e->getMessage() . PHP_EOL);
        }
    }
}
