<?php
/**
 * Fired during plugin deactivation.
 *
 * This class defines all code necessary to run during the plugin's deactivation.
 *
 * @since      2.0.0
 * @package    WP_Cache_On
 * @subpackage WP_Cache_On/includes
 * @author     Jeffrey Cooper <email@example.com>
 */
class WP_Cache_On_Deactivator
{
    /**
     * Short Description. (use period)
     *
     * Long Description.
     *
     * @since    1.0.0
     */
    public static function deactivate()
    {
        WP_Cache_On_Disk::clear_total_cache(true);
        WP_Cache_On_General::htaccess_action(false);
        unlink(WP_CONTENT_DIR . '/advanced-cache.php'); //Remove plugin file from WP content dir
    }

    /**
     * Uninstall per multisite blog
     */
    public static function on_uninstall()
    {
        global $wpdb;

        if (is_multisite() && !empty($_GET['networkwide'])) {
            $old = $wpdb->blogid; // legacy blog
            $ids = WP_Cache_On_General::_get_blog_ids(); // blog id

            //Uninstall per blog
            foreach ($ids as $id) {
                switch_to_blog($id);
                self::_uninstall_backend();
            }

            switch_to_blog($old); //Restore
        } else {
            self::_uninstall_backend();
        }
    }

    /**
     * Uninstall
     */
    private static function _uninstall_backend()
    {
        delete_option('wp-cache-on');
        WP_Cache_On_Disk::clear_total_cache(true);
    }
}
