<?php
/**
 * Plugin Name
 *
 * @package           WP_Cache_On
 * @author            Jeffrey Cooper
 * @copyright         2020 Jeffrey Cooper
 * @license           GPL-2.0-or-later
 *
 * @wordpress-plugin
 * Plugin Name:       WPCacheOn
 * Plugin URI:        https://wordpress.org/plugins/wpcacheon/
 * Description:       Simple and powerful cache plugin for WordPress. Install and activate, that simple, your website is already loading faster!
 * Version:           2.0.1
 * Requires at least: 4.6
 * Requires PHP:      5.6
 * Author:            Jeffrey Cooper
 * Author URI:        https://wpcacheon.io
 * Text Domain:       wpcacheon
 * Domain Path:       /languages/
 * License:           GPL v2 or later
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

/**
 * Currently plugin version.
 */
define('WCO_VERSION', '2.0.1');
define('WCO_FILE', __FILE__);
define('WCO_DIR', dirname(__FILE__));
define('WCO_BASE', plugin_basename(__FILE__));
define("WCO_PLUGIN_DIR_PATH", plugins_url('', __FILE__));
define('WCO_CACHE_DIR', WP_CONTENT_DIR . '/cache/wpcacheon');
define('WCO_MIN_WP', '4.1');

spl_autoload_register('autoload');

function autoload($className)
{
    //Make if work for pluggin class only
    if (strpos($className, 'WP_Cache_On') !== false) {
        $dir = 'includes';

        if (strpos($className, 'Admin') !== false) {
            $dir = 'admin';
        } else if (strpos($className, 'Public') !== false) {
            $dir = 'public';
        }

        $path         = sprintf('%s/%s/class-%s.php', WCO_DIR, $dir, strtolower(str_replace('_', '-', $className)));
        $pathPartials = sprintf('%s/%s/%s.php', WCO_DIR, $dir . "/partials", strtolower(str_replace('_', '-', $className)));

        if (file_exists($path)) {
            require_once $path;
        }

        if (file_exists($pathPartials)) {
            require_once $pathPartials;
        }

    }
}

register_activation_hook(__FILE__, array('WP_Cache_On_Activator', 'activate'));
register_deactivation_hook(__FILE__, array('WP_Cache_On_Deactivator', 'deactivate'));

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wp_cache_on()
{
    $plugin = new WP_Cache_On();
    $plugin->run();
}
run_wp_cache_on();
